.First.lib <- function(lib, pkg) {
require( tcltk)
require( ismev)
extremes.gui()
cat("\n", "Package extRemes: For a tutorial and more information go to", "\n")
cat("http://www.esig.ucar.edu/extremevalues/evtk.html", "\n")
} # end of '.First.lib' fcn
